@@ -1,7 +1,7 @@
 """
 Type annotations for amp service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/literals.html)
+[Open documentation](./literals.md)
 
 Usage::
 
@@ -19,8 +19,8 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("ListWorkspacesPaginatorName", "WorkspaceStatusCode")
+__all__ = ("ListWorkspacesPaginatorName", "WorkspaceStatusCodeType")
 
 
 ListWorkspacesPaginatorName = Literal["list_workspaces"]
-WorkspaceStatusCode = Literal["ACTIVE", "CREATING", "CREATION_FAILED", "DELETING", "UPDATING"]
+WorkspaceStatusCodeType = Literal["ACTIVE", "CREATING", "CREATION_FAILED", "DELETING", "UPDATING"]
